==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "收到的共享",
    "Nothing shared with you yet" : "您还没有收到任何共享的文件",
    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
    "Shared with others" : "您共享的文件",
    "Nothing shared yet" : "还没有共享过文件",
    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
    "Shared by link" : "通过链接共享",
    "No shared links" : "无共享链接",
    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
    "Deleted shares" : "已删除的共享",
    "No deleted shares" : "没有删除的共享",
    "Shares you deleted will show up here" : "您删除的共享将在这里显示",
    "Pending shares" : "待定共享",
    "No pending shares" : "没有待定共享",
    "Shares you have received but not confirmed will show up here" : "您收到但未确认的共享将显示在这里",
    "Shares" : "共享",
    "No shares" : "没有共享",
    "Shares will show up here" : "共享将在这里显示",
    "Restore share" : "恢复共享",
    "Something happened. Unable to restore the share." : "发生了问题。无法恢复该共享。",
    "Accept share" : "接受共享",
    "Something happened. Unable to accept the share." : "发生了问题。无法接受该共享。",
    "Reject share" : "拒绝共享",
    "Something happened. Unable to reject the share." : "发生了问题。无法拒绝该共享。",
    "This will stop your current uploads." : "此操作将终止您当前的上传。",
    "Move or copy" : "移动或复制",
    "Download" : "下载",
    "Delete" : "删除",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "Terms of service" : "服务条款",
    "No compatible server found at {remote}" : " {remote} 未发现匹配的服务器",
    "Invalid server URL" : "无效的服务器地址",
    "Failed to add the public link to your Nextcloud" : "无法添加公开链接到您的 Nextcloud",
    "No expiration date set" : "未设置失效时间",
    "Shared by" : "共享人",
    "File shares" : "文件共享",
    "Downloaded via public link" : "通过公开链接下载",
    "Downloaded by {email}" : "已被 {email} 下载",
    "{file} downloaded via public link" : "{file} 被通过公开链接下载",
    "{email} downloaded {file}" : "{email} 已下载 {file}",
    "Shared with group {group}" : "共享到群组 {group}",
    "Removed share for group {group}" : "到群组 {group} 的共享已被移除 ",
    "{actor} shared with group {group}" : "{actor}  被共享到群组 {group}",
    "{actor} removed share for group {group}" : "{actor} 删除了群组 {group} 的共享",
    "Share for group {group} expired" : "给分组 {group} 的共享已过期",
    "You shared {file} with group {group}" : "您与群组 {group} 共享了 {file} ",
    "You removed group {group} from {file}" : "已从 {file} 移除组 {group}",
    "{actor} shared {file} with group {group}" : " {actor} 与群组 {group} 共享了 {file} ",
    "{actor} removed group {group} from {file}" : "{actor} 从 {file} 删除群组 {group} ",
    "Share for file {file} with group {group} expired" : "与分组 {group} 的文件共享 {file} 已过期",
    "Shared as public link" : "共享为公开链接",
    "Removed public link" : "移除公开链接",
    "Public link expired" : "公开链接已过期",
    "{actor} shared as public link" : "{actor} 公共链接共享",
    "{actor} removed public link" : "{actor} 删除公共链接",
    "Public link of {actor} expired" : "{actor} 的公开链接已过期",
    "You shared {file} as public link" : "您共享了 {file} 为公开链接",
    "You removed public link for {file}" : "您移除了 {file} 的公开链接",
    "Public link expired for {file}" : "{file} 的公开链接已过期",
    "{actor} shared {file} as public link" : "{actor} 用公开链接共享了 {file} ",
    "{actor} removed public link for {file}" : "{actor} 删除了 {file} 的公开链接",
    "Public link of {actor} for {file} expired" : "{actor} 为 {file} 创建的公开链接已过期",
    "{user} accepted the remote share" : "{user} 接受了远程共享",
    "{user} declined the remote share" : "{user} 拒绝了远程共享",
    "You received a new remote share {file} from {user}" : "您收到了一个来自 {user} 的远程共享 {file} ",
    "{user} accepted the remote share of {file}" : "{user} 接受了 {file} 的远程共享",
    "{user} declined the remote share of {file}" : "{user} 拒绝了 {file} 的远程共享",
    "{user} unshared {file} from you" : "你取消了 {user} 共享的文件 {file}",
    "Shared with {user}" : "与 {user} 共享",
    "Removed share for {user}" : "移除给 {user} 的共享",
    "You removed yourself" : "您移除了您自己",
    "{actor} removed themselves" : "{actor} 移除了他们自己",
    "{actor} shared with {user}" : "{actor} 与 {user} 共享",
    "{actor} removed share for {user}" : "{actor} 删除了与 {user} 的共享",
    "Shared by {actor}" : "由 {actor} 共享",
    "{actor} removed share" : "{actor} 移除共享",
    "Share for {user} expired" : "给 {user} 的共享已过期",
    "Share expired" : "共享已过期",
    "You shared {file} with {user}" : "您与 {user} 共享了 {file} ",
    "You removed {user} from {file}" : "您从 {file} 移除了 {user} ",
    "You removed yourself from {file}" : "您从 {file} 移除了您自己",
    "{actor} removed themselves from {file}" : "{actor} 从 {file} 移除了他们自己",
    "{actor} shared {file} with {user}" : "{actor} 共享 {file} 与 {user}",
    "{actor} removed {user} from {file}" : "{actor} 从 {file} 移除了 {user}",
    "{actor} shared {file} with you" : "{actor} 与您共享了 {file} ",
    "{actor} removed you from the share named {file}" : "{actor} 从名为 {file} 的共享中移除了您",
    "Share for file {file} with {user} expired" : "与 {user} 的文件共享 {file} 已过期",
    "Share for file {file} expired" : "文件 {file} 的共享已过期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "通过邮件或公共链接共享的文件或文件夹<strong>已下载</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "Shared link" : "已共享的链接",
    "Wrong share ID, share doesn't exist" : "错误的共享 ID，共享不存在",
    "Could not delete share" : "不能删除共享",
    "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
    "Wrong path, file/folder doesn't exist" : "路径错误，文件或文件夹不存在",
    "Could not create share" : "无法创建共享",
    "invalid permissions" : "无效的权限",
    "Please specify a valid user" : "请指定一个有效的用户",
    "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
    "Please specify a valid group" : "请指定一个有效的组",
    "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送 %s 共享密码失败。",
    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
    "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
    "Please specify a valid circle" : "请指明一个可用圈子",
    "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
    "Unknown share type" : "未知共享类型",
    "Not a directory" : "不是一个目录",
    "Could not lock node" : "无法锁定节点",
    "Could not lock path" : "无法锁定路径",
    "Wrong or no update parameter given" : "错误或没有更新参数给出",
    "Can't change permissions for public share links" : "不能改变公共共享链接权限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送共享密码失败。",
    "shared by %s" : "共享者 %s",
    "Download all files" : "下载所有文件",
    "Direct link" : "直接链接",
    "Add to your Nextcloud" : "添加到您的 Nextcloud",
    "Share API is disabled" : "共享 API 已被禁用",
    "File sharing" : "文件共享",
    "Share will expire tomorrow" : "共享将在明天过期",
    "One or more of your shares will expire tomorrow" : "您的一个或多个共享将在明天过期",
    "Your share of {node} will expire tomorrow" : "您在{node}的共享将在明天过期",
    "You received {share} as a share by {user}" : "您收到了 {user} 共享的 {share}",
    "You received {share} to group {group} as a share by {user}" : "您收到了来自 {user} 的共享给分组 {group} 的 {share}",
    "Accept" : "接受",
    "Reject" : "拒绝",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
    "Sharing" : "共享",
    "Accept user and group shares by default" : "默认接受用户和分组共享",
    "Allow editing" : "允许编辑",
    "Allow creating" : "允许创建",
    "Allow deleting" : "允许删除",
    "Allow resharing" : "允许二次共享",
    "Expiration date enforced" : "强制过期日期",
    "Set expiration date" : "设置过期日期",
    "Enter a date" : "输入日期",
    "Note to recipient" : "接收人备注",
    "Unshare" : "取消共享",
    "group" : "分组",
    "conversation" : "会话",
    "remote" : "远程",
    "remote group" : "远程分组",
    "guest" : "访客",
    "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
    "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
    "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
    "Added by {initiator}" : "由 {initiator} 添加",
    "Via folder" : "通过文件夹",
    "Internal link" : "内部链接",
    "Link copied" : "已复制链接",
    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
    "Copy to clipboard" : "复制到剪贴板",
    "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
    "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
    "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
    "Password protection (enforced)" : "密码保护（强制）",
    "Password protection" : "密码保护",
    "Enter a password" : "输入密码",
    "Expiration date (enforced)" : "过期日期（强制）",
    "Cancel" : "取消",
    "Read only" : "只读",
    "Allow upload and editing" : "允许上传和编辑",
    "File drop (upload only)" : "文件拖拽（仅上传）",
    "Hide download" : "隐藏下载",
    "Password protect" : "密码保护",
    "Video verification" : "视频验证",
    "Enter a note for the share recipient" : "给共享接收人留备注",
    "Add another link" : "添加其他链接",
    "Create a new share link" : "创建新的共享链接",
    "Shared via link by {initiator}" : "由 {initiator} 通过链接共享",
    "Share link" : "共享链接",
    "Error, please enter proper password and/or expiration date" : "错误，请输入正确的密码和/或过期日期",
    "No recommendations. Start typing." : "没有推荐。开始输入。",
    "Resharing is not allowed" : "不允许二次共享",
    "Name or email address …" : "名称或电子邮箱地址...",
    "Name or federated cloud ID …" : "名称或联合云 ID…",
    "Name, federated cloud ID or email address …" : "名称，联合云 ID 或电子邮件地址…",
    "Name …" : "名称 …",
    "Searching …" : "正在搜索 ...",
    "No elements found." : "未发现元素。",
    "Search globally" : "全局搜索",
    "on {server}" : "在 {server} 上",
    "Others with access" : "其他具有访问权限的人",
    "No other users with access found" : "找不到其他具有访问权限的用户",
    "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
    "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
    "Unable to fetch inherited shares" : "无法获取继承的共享",
    "Unable to load the shares list" : "无法加载共享列表",
    "Expires {relativetime}" : "过期 {relativetime}",
    "this share just expired." : "此共享已过期。",
    "Link to a file" : "链接到文件",
    "Error creating the share" : "创建共享时出错",
    "Shared" : "已共享",
    "Share" : "共享",
    "Shared with" : "共享给",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "由{owner} 共享给您及对话 {conversation}",
    "Shared with you in a conversation by {owner}" : "由 {owner} 在一个会话中共享给您",
    "Shared with you by {owner}" : "{owner} 与您共享",
    "No entries found in this folder" : "在此文件夹中找不到项目",
    "Name" : "名称",
    "Share time" : "共享时间",
    "Expiration date" : "过期日期 ",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效。",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "已禁用共享",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给您该链接的人。",
    "Share note" : "共享笔记",
    "Toggle grid view" : "切换网格视图",
    "Download %s" : "下载 %s",
    "Upload files to %s" : "上传文件到 %s",
    "Note" : "备注",
    "Select or drop files" : "选择或删除文件",
    "Uploading files…" : "正在上传文件... ",
    "Uploaded files:" : "上传的文件： ",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
    "could not delete share" : "无法删除共享"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "收到的共享",
    "Nothing shared with you yet" : "您还没有收到任何共享的文件",
    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
    "Shared with others" : "您共享的文件",
    "Nothing shared yet" : "还没有共享过文件",
    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
    "Shared by link" : "通过链接共享",
    "No shared links" : "无共享链接",
    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
    "Deleted shares" : "已删除的共享",
    "No deleted shares" : "没有删除的共享",
    "Shares you deleted will show up here" : "您删除的共享将在这里显示",
    "Pending shares" : "待定共享",
    "No pending shares" : "没有待定共享",
    "Shares you have received but not confirmed will show up here" : "您收到但未确认的共享将显示在这里",
    "Shares" : "共享",
    "No shares" : "没有共享",
    "Shares will show up here" : "共享将在这里显示",
    "Restore" : "恢复",
    "Restore share" : "恢复共享",
    "Something happened. Unable to restore the share." : "发生了问题。无法恢复该共享。",
    "Accept share" : "接受共享",
    "Something happened. Unable to accept the share." : "发生了问题。无法接受该共享。",
    "Reject share" : "拒绝共享",
    "Something happened. Unable to reject the share." : "发生了问题。无法拒绝该共享。",
    "Waiting…" : "等待中...",
    "error" : "错误",
    "finished" : "完成",
    "This will stop your current uploads." : "此操作将终止您当前的上传。",
    "Move or copy" : "移动或复制",
    "Download" : "下载",
    "Delete" : "删除",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "Terms of service" : "服务条款",
    "No compatible server found at {remote}" : " {remote} 未发现匹配的服务器",
    "Invalid server URL" : "无效的服务器地址",
    "Failed to add the public link to your Nextcloud" : "无法添加公开链接到您的 Nextcloud",
    "No expiration date set" : "未设置失效时间",
    "Shared by" : "共享人",
    "File shares" : "文件共享",
    "Downloaded via public link" : "通过公开链接下载",
    "Downloaded by {email}" : "已被 {email} 下载",
    "{file} downloaded via public link" : "{file} 被通过公开链接下载",
    "{email} downloaded {file}" : "{email} 已下载 {file}",
    "Shared with group {group}" : "共享到群组 {group}",
    "Removed share for group {group}" : "到群组 {group} 的共享已被移除 ",
    "{actor} shared with group {group}" : "{actor}  被共享到群组 {group}",
    "{actor} removed share for group {group}" : "{actor} 删除了群组 {group} 的共享",
    "Share for group {group} expired" : "给分组 {group} 的共享已过期",
    "You shared {file} with group {group}" : "您与群组 {group} 共享了 {file} ",
    "You removed group {group} from {file}" : "已从 {file} 移除组 {group}",
    "{actor} shared {file} with group {group}" : " {actor} 与群组 {group} 共享了 {file} ",
    "{actor} removed group {group} from {file}" : "{actor} 从 {file} 删除群组 {group} ",
    "Share for file {file} with group {group} expired" : "与分组 {group} 的文件共享 {file} 已过期",
    "Shared as public link" : "共享为公开链接",
    "Removed public link" : "移除公开链接",
    "Public link expired" : "公开链接已过期",
    "{actor} shared as public link" : "{actor} 公共链接共享",
    "{actor} removed public link" : "{actor} 删除公共链接",
    "Public link of {actor} expired" : "{actor} 的公开链接已过期",
    "You shared {file} as public link" : "您共享了 {file} 为公开链接",
    "You removed public link for {file}" : "您移除了 {file} 的公开链接",
    "Public link expired for {file}" : "{file} 的公开链接已过期",
    "{actor} shared {file} as public link" : "{actor} 用公开链接共享了 {file} ",
    "{actor} removed public link for {file}" : "{actor} 删除了 {file} 的公开链接",
    "Public link of {actor} for {file} expired" : "{actor} 为 {file} 创建的公开链接已过期",
    "{user} accepted the remote share" : "{user} 接受了远程共享",
    "{user} declined the remote share" : "{user} 拒绝了远程共享",
    "You received a new remote share {file} from {user}" : "您收到了一个来自 {user} 的远程共享 {file} ",
    "{user} accepted the remote share of {file}" : "{user} 接受了 {file} 的远程共享",
    "{user} declined the remote share of {file}" : "{user} 拒绝了 {file} 的远程共享",
    "{user} unshared {file} from you" : "你取消了 {user} 共享的文件 {file}",
    "Shared with {user}" : "与 {user} 共享",
    "Removed share for {user}" : "移除给 {user} 的共享",
    "You removed yourself" : "您移除了您自己",
    "{actor} removed themselves" : "{actor} 移除了他们自己",
    "{actor} shared with {user}" : "{actor} 与 {user} 共享",
    "{actor} removed share for {user}" : "{actor} 删除了与 {user} 的共享",
    "Shared by {actor}" : "由 {actor} 共享",
    "{actor} removed share" : "{actor} 移除共享",
    "Share for {user} expired" : "给 {user} 的共享已过期",
    "Share expired" : "共享已过期",
    "You shared {file} with {user}" : "您与 {user} 共享了 {file} ",
    "You removed {user} from {file}" : "您从 {file} 移除了 {user} ",
    "You removed yourself from {file}" : "您从 {file} 移除了您自己",
    "{actor} removed themselves from {file}" : "{actor} 从 {file} 移除了他们自己",
    "{actor} shared {file} with {user}" : "{actor} 共享 {file} 与 {user}",
    "{actor} removed {user} from {file}" : "{actor} 从 {file} 移除了 {user}",
    "{actor} shared {file} with you" : "{actor} 与您共享了 {file} ",
    "{actor} removed you from the share named {file}" : "{actor} 从名为 {file} 的共享中移除了您",
    "Share for file {file} with {user} expired" : "与 {user} 的文件共享 {file} 已过期",
    "Share for file {file} expired" : "文件 {file} 的共享已过期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "通过邮件或公共链接共享的文件或文件夹<strong>已下载</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
    "Files" : "文件",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "Shared link" : "已共享的链接",
    "Wrong share ID, share doesn't exist" : "错误的共享 ID，共享不存在",
    "Could not delete share" : "不能删除共享",
    "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
    "Wrong path, file/folder doesn't exist" : "路径错误，文件或文件夹不存在",
    "Could not create share" : "无法创建共享",
    "invalid permissions" : "无效的权限",
    "Please specify a valid user" : "请指定一个有效的用户",
    "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
    "Please specify a valid group" : "请指定一个有效的组",
    "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送 %s 共享密码失败。",
    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
    "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
    "Please specify a valid circle" : "请指明一个可用圈子",
    "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
    "Unknown share type" : "未知共享类型",
    "Not a directory" : "不是一个目录",
    "Could not lock node" : "无法锁定节点",
    "Could not lock path" : "无法锁定路径",
    "Wrong or no update parameter given" : "错误或没有更新参数给出",
    "Can't change permissions for public share links" : "不能改变公共共享链接权限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送共享密码失败。",
    "shared by %s" : "共享者 %s",
    "Download all files" : "下载所有文件",
    "Direct link" : "直接链接",
    "Add to your Nextcloud" : "添加到您的 Nextcloud",
    "Share API is disabled" : "共享 API 已被禁用",
    "File sharing" : "文件共享",
    "Share will expire tomorrow" : "共享将在明天过期",
    "One or more of your shares will expire tomorrow" : "您的一个或多个共享将在明天过期",
    "Your share of {node} will expire tomorrow" : "您在{node}的共享将在明天过期",
    "You received {share} as a share by {user}" : "您收到了 {user} 共享的 {share}",
    "You received {share} to group {group} as a share by {user}" : "您收到了来自 {user} 的共享给分组 {group} 的 {share}",
    "Accept" : "接受",
    "Reject" : "拒绝",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
    "Sharing" : "共享",
    "Accept user and group shares by default" : "默认接受用户和分组共享",
    "Allow editing" : "允许编辑",
    "Allow creating" : "允许创建",
    "Allow deleting" : "允许删除",
    "Allow resharing" : "允许二次共享",
    "Expiration date enforced" : "强制过期日期",
    "Set expiration date" : "设置过期日期",
    "Enter a date" : "输入日期",
    "Note to recipient" : "接收人备注",
    "Unshare" : "取消共享",
    "group" : "分组",
    "conversation" : "会话",
    "remote" : "远程",
    "remote group" : "远程分组",
    "guest" : "访客",
    "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
    "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
    "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
    "Added by {initiator}" : "由 {initiator} 添加",
    "Via “{folder}”" : "通过 “{folder}”",
    "Internal link" : "内部链接",
    "Link copied" : "已复制链接",
    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
    "Copy to clipboard" : "复制到剪贴板",
    "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
    "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
    "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
    "Password protection (enforced)" : "密码保护（强制）",
    "Password protection" : "密码保护",
    "Enter a password" : "输入密码",
    "Expiration date (enforced)" : "过期日期（强制）",
    "Cancel" : "取消",
    "Share label" : "分享标签",
    "Read only" : "只读",
    "Allow upload and editing" : "允许上传和编辑",
    "File drop (upload only)" : "文件拖拽（仅上传）",
    "Hide download" : "隐藏下载",
    "Password protect" : "密码保护",
    "Video verification" : "视频验证",
    "Enter a note for the share recipient" : "给共享接收人留备注",
    "Add another link" : "添加其他链接",
    "Create a new share link" : "创建新的共享链接",
    "Shared via link by {initiator}" : "由 {initiator} 通过链接共享",
    "Share link ({label})" : "分享链接({标签})",
    "Share link" : "共享链接",
    "Error, please enter proper password and/or expiration date" : "错误，请输入正确的密码和/或过期日期",
    "No recommendations. Start typing." : "没有推荐。开始输入。",
    "Resharing is not allowed" : "不允许二次共享",
    "Searching …" : "正在搜索 ...",
    "No elements found." : "未发现元素。",
    "Search globally" : "全局搜索",
    "on {server}" : "在 {server} 上",
    "Others with access" : "其他具有访问权限的人",
    "No other users with access found" : "找不到其他具有访问权限的用户",
    "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
    "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
    "Unable to fetch inherited shares" : "无法获取继承的共享",
    "Unable to load the shares list" : "无法加载共享列表",
    "Expires {relativetime}" : "过期 {relativetime}",
    "this share just expired." : "此共享已过期。",
    "Link to a file" : "链接到文件",
    "Error creating the share" : "创建共享时出错",
    "Error updating the share" : "更新共享时出错",
    "Shared" : "已共享",
    "Share" : "共享",
    "Shared with" : "共享给",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "由{owner} 共享给您及对话 {conversation}",
    "Shared with you in a conversation by {owner}" : "由 {owner} 在一个会话中共享给您",
    "Shared with you by {owner}" : "{owner} 与您共享",
    "No entries found in this folder" : "在此文件夹中找不到项目",
    "Name" : "名称",
    "Share time" : "共享时间",
    "Expiration date" : "过期日期 ",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效。",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "已禁用共享",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给您该链接的人。",
    "Share note" : "共享笔记",
    "Toggle grid view" : "切换网格视图",
    "Download %s" : "下载 %s",
    "Upload files to %s" : "上传文件到 %s",
    "Note" : "备注",
    "Select or drop files" : "选择或删除文件",
    "Uploading files" : "正在上传文件",
    "Uploaded files:" : "上传的文件： ",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
    "Name or email address …" : "名称或电子邮箱地址...",
    "Name or federated cloud ID …" : "名称或联合云 ID…",
    "Name, federated cloud ID or email address …" : "名称，联合云 ID 或电子邮件地址…",
    "Name …" : "名称 …",
    "Uploading files…" : "正在上传文件... "
},
"nplurals=1; plural=0;");
